@@ -3,7 +3,7 @@ BEGIN {
   $lib::absolute::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $lib::absolute::VERSION = '0.003';
+  $lib::absolute::VERSION = '0.004';
 }
 # ABSTRACT: Convert all paths in @INC to absolute paths
 
@@ -30,7 +30,17 @@ sub import {
 
 1;
 
-=encoding utf8
+
+__END__
+=pod
+
+=head1 NAME
+
+lib::absolute - Convert all paths in @INC to absolute paths
+
+=head1 VERSION
+
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -43,6 +53,8 @@ sub import {
 This package converts on load all your @INC path into absolute paths, if you have "." in your path, it gets additionally
 added again (and also get added as absolute path).
 
+=encoding utf8
+
 =head1 SUPPORT
 
 IRC
@@ -53,9 +65,21 @@ Repository
 
   http://github.com/Getty/p5-lib-absolute
   Pull request and additional contributors are welcome
- 
+
 Issue Tracker
 
   http://github.com/Getty/p5-lib-absolute/issues
 
+=head1 AUTHOR
+
+Torsten Raudssus <torsten@raudss.us>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Torsten Raudssus.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
 
